@@ -7,44 +7,33 @@
 #include "editorplugins/editorplugininterface.h"
 #include "logging_p.h"
 
-
 using namespace GraphTheory;
 
 class GraphTheory::EditorPluginInterfacePrivate
 {
 public:
-    EditorPluginInterfacePrivate(const QString &componentName)
-        : m_componentName(componentName)
+    EditorPluginInterfacePrivate(const KPluginMetaData &data)
+        : m_componentName(data.pluginId())
+        , m_displayName(data.name())
     {
-
     }
 
     const QString m_componentName;
-    QString m_displayName;
-    QString m_lastErrorString;
+    const QString m_displayName;
 };
 
-EditorPluginInterface::EditorPluginInterface(const QString &componentName, QObject *parent)
+EditorPluginInterface::EditorPluginInterface(QObject *parent, const KPluginMetaData &data)
     : QObject(parent)
-    , d(new EditorPluginInterfacePrivate(componentName))
+    , d(new EditorPluginInterfacePrivate(data))
 {
-
 }
 
-EditorPluginInterface::~EditorPluginInterface()
-{
+EditorPluginInterface::~EditorPluginInterface() = default;
 
-}
-
-QString EditorPluginInterface::displayName()
+QString EditorPluginInterface::displayName() const
 {
     if (d->m_displayName.isEmpty()) {
         return d->m_componentName;
     }
     return d->m_displayName;
 }
-
-void EditorPluginInterface::setDisplayName(const QString &name)
-{
-    d->m_displayName = name;
-}
