@@ -7,65 +7,43 @@
 #include "editorpluginmanager.h"
 #include "logging_p.h"
 
-#include <KPluginMetaData>
 #include <KPluginFactory>
-#include <QString>
+#include <KPluginMetaData>
 #include <QCoreApplication>
 #include <QDir>
 #include <QDirIterator>
 #include <QJsonArray>
 #include <QJsonObject>
+#include <QString>
 
 using namespace GraphTheory;
 
 class GraphTheory::EditorPluginManagerPrivate
 {
 public:
-    EditorPluginManagerPrivate()
-    {
-
-    }
-
-    ~EditorPluginManagerPrivate()
-    { }
-
-    QList<EditorPluginInterface*> m_plugins;
+    QList<EditorPluginInterface *> m_plugins;
 };
 
 EditorPluginManager::EditorPluginManager()
     : d(new EditorPluginManagerPrivate)
 {
-    loadPlugins();
-}
-
-EditorPluginManager::~EditorPluginManager()
-{
-
-}
-
-QList<EditorPluginInterface*> EditorPluginManager::plugins() const
-{
-    return d->m_plugins;
-}
-
-void EditorPluginManager::loadPlugins()
-{
-    // remove all present plugins
-    qDeleteAll(d->m_plugins);
-    d->m_plugins.clear();
-
     // load plugins
     const QVector<KPluginMetaData> metadataList = KPluginMetaData::findPlugins(QStringLiteral("rocs/editorplugins"));
     for (const auto &metadata : metadataList) {
         const auto result = KPluginFactory::instantiatePlugin<EditorPluginInterface>(metadata, this);
 
-        if (!result) {
+        if (result) {
+            d->m_plugins.append(result.plugin);
+            qCDebug(GRAPHTHEORY_GENERAL) << "Loaded editor plugin:" << metadata.pluginId();
+        } else {
             qCWarning(GRAPHTHEORY_GENERAL) << "Failed to load editor plugin" << result.errorText;
-            continue;
         }
-
-        result.plugin->setDisplayName(metadata.name());
-        d->m_plugins.append(result.plugin);
-        qCDebug(GRAPHTHEORY_GENERAL) << "Loaded plugin:" << metadata.name();
     }
 }
+
+EditorPluginManager::~EditorPluginManager() = default;
+
+QList<EditorPluginInterface *> EditorPluginManager::plugins() const
+{
+    return d->m_plugins;
+}
