@@ -5,14 +5,14 @@
  */
 
 #include "transformedgeswidget.h"
-#include "graphdocument.h"
 #include "edge.h"
+#include "graphdocument.h"
 #include "modifiers/topology.h"
 
 #include <KLocalizedString>
+#include <QDebug>
 #include <QMap>
 #include <QPair>
-#include <QDebug>
 
 using namespace GraphTheory;
 
@@ -60,8 +60,9 @@ void TransformEdgesWidget::transform()
 
 void TransformEdgesWidget::makeComplete()
 {
-    //TODO only default edge type considered
-    foreach(EdgePtr e, m_document->edges()) {
+    // TODO only default edge type considered
+    const auto edges = m_document->edges();
+    for (const EdgePtr &e : edges) {
         e->destroy();
     }
 
@@ -77,21 +78,24 @@ void TransformEdgesWidget::makeComplete()
 
 void TransformEdgesWidget::removeAllEdges()
 {
-    //TODO only default edge type considered
-    foreach(EdgePtr e, m_document->edges()) {
+    // TODO only default edge type considered
+    const auto edges = m_document->edges();
+    for (const EdgePtr &e : edges) {
         e->destroy();
     }
 }
 
 void TransformEdgesWidget::reverseAllEdges()
 {
-    foreach (EdgeTypePtr type , m_document->edgeTypes()) {
+    const auto edgeTypes = m_document->edgeTypes();
+    for (const EdgeTypePtr &type : edgeTypes) {
         if (type->direction() == EdgeType::Bidirectional) {
             continue;
         }
-        QList< QPair< NodePtr, NodePtr > > newEdges;
-        foreach(EdgePtr e, m_document->edges(type)) {
-            newEdges << QPair< NodePtr, NodePtr >(e->to(), e->from());
+        QList<QPair<NodePtr, NodePtr>> newEdges;
+        const auto edges = m_document->edges(type);
+        for (const EdgePtr &e : edges) {
+            newEdges << QPair<NodePtr, NodePtr>(e->to(), e->from());
             e->destroy();
         }
 
@@ -108,7 +112,7 @@ qreal TransformEdgesWidget::makeSpanningTree()
     int n = nodes.size();
 
     // the resulting spanning tree (MST)
-    QList< QPair<int, int> > MST;
+    QList<QPair<int, int>> MST;
 
     /*
      * distance[i] denotes the distance between node i and the minimum spanning
@@ -133,11 +137,12 @@ qreal TransformEdgesWidget::makeSpanningTree()
      * path is present between i and j in the previous tree the weight
      * must be set to 0.
      */
-    QMap< QPair<int, int>, qreal> weight;
+    QMap<QPair<int, int>, qreal> weight;
 
     for (int i = 0; i < n; i++) {
         for (int j = 0; j < n; j++) {
-            if (i == j)   weight[QPair<int, int>(i, j)] = 0;
+            if (i == j)
+                weight[QPair<int, int>(i, j)] = 0;
 
             EdgeList out;
             out = nodes[i]->edges();
@@ -148,7 +153,6 @@ qreal TransformEdgesWidget::makeSpanningTree()
                         weight[QPair<int, int>(i, j)] = out[k]->property("value").toDouble();
                     else
                         weight[QPair<int, int>(i, j)] = 1;
-
                 }
             }
         }
@@ -158,7 +162,7 @@ qreal TransformEdgesWidget::makeSpanningTree()
      * successor[i] denotes the index of the node, to which i must be
      * linked to in order to get distance distance[i]
      */
-    QMap< int, int> successor;
+    QMap<int, int> successor;
 
     // start with first graph node
     inTree[0] = true;
@@ -166,7 +170,7 @@ qreal TransformEdgesWidget::makeSpanningTree()
     // update distances
     for (int i = 0; i < n; ++i) {
         if ((weight[QPair<int, int>(0, i)] != 0) && (distance[i] > weight[QPair<int, int>(0, i)])) {
-            distance[i] = weight[QPair<int, int>(0, i)] ;
+            distance[i] = weight[QPair<int, int>(0, i)];
             successor[i] = 0;
         }
     }
@@ -190,7 +194,7 @@ qreal TransformEdgesWidget::makeSpanningTree()
 
         // update distances
         for (int i = 0; i < n; ++i) {
-            if ((weight[QPair<int, int>(min, i)]  != 0) && (distance[i] > weight[QPair<int, int>(min, i)])) {
+            if ((weight[QPair<int, int>(min, i)] != 0) && (distance[i] > weight[QPair<int, int>(min, i)])) {
                 distance[i] = weight[QPair<int, int>(min, i)];
                 successor[i] = min;
             }
@@ -215,7 +219,8 @@ qreal TransformEdgesWidget::makeSpanningTree()
 
 void TransformEdgesWidget::removeAllSelfEdges()
 {
-    foreach(EdgePtr e, m_document->edges()) {
+    const auto edges = m_document->edges();
+    for (const EdgePtr &e : edges) {
         if (e->to() == e->from()) {
             e->destroy();
         }
