@@ -9,30 +9,31 @@
 #include "testdotfileformat.h"
 #include "../dotfileformat.h"
 #include "../dotgrammar.h"
+#include "edge.h"
 #include "fileformats/fileformatinterface.h"
 #include "graphdocument.h"
-#include "node.h"
-#include "edge.h"
 #include "logging_p.h"
-#include <string>
+#include "node.h"
+#include <QTemporaryFile>
 #include <QTest>
 #include <QUrl>
-#include <QTemporaryFile>
+#include <string>
 
 using namespace GraphTheory;
 
 static const std::string simple = "digraph simple {a_2 -> b; c; d -> e /* error -> comment*/}";
 
-static const std::string subgraph = "digraph trees {"
-                                        "  subgraph t {"
-                                        "    0 -> \"1\" [label = \"A\"];"
-                                        "    0 -> \"2\" [label = \"B\"];"
-                                        "  }"
-                                        "  subgraph u {"
-                                        "    Animal -> Cat [label = \"feline\"];"
-                                        "    Animal -> Dot [label = \"canine\"];"
-                                        "  }"
-                                        "}";
+static const std::string subgraph =
+    "digraph trees {"
+    "  subgraph t {"
+    "    0 -> \"1\" [label = \"A\"];"
+    "    0 -> \"2\" [label = \"B\"];"
+    "  }"
+    "  subgraph u {"
+    "    Animal -> Cat [label = \"feline\"];"
+    "    Animal -> Dot [label = \"canine\"];"
+    "  }"
+    "}";
 
 void DotFileFormatTest::checkNodes(GraphDocumentPtr document, QList<QString> nodeNames)
 {
@@ -45,7 +46,7 @@ void DotFileFormatTest::checkNodes(GraphDocumentPtr document, QList<QString> nod
         QString name = node->dynamicProperty("name").toString();
         int index = nodeNames.indexOf(name);
         if (index == -1) {
-            qCDebug(GRAPHTHEORY_FILEFORMAT) << "Node "<< name << " was created unnecessarily.";
+            qCDebug(GRAPHTHEORY_FILEFORMAT) << "Node " << name << " was created unnecessarily.";
         }
         QVERIFY(index != -1);
         nodeNames.removeAt(index);
@@ -55,7 +56,6 @@ void DotFileFormatTest::checkNodes(GraphDocumentPtr document, QList<QString> nod
 
 void DotFileFormatTest::init()
 {
-
 }
 
 void DotFileFormatTest::simpleGraphParsing()
@@ -75,7 +75,7 @@ void DotFileFormatTest::parseSubgraphs()
 void DotFileFormatTest::parseFileER()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("undirected/ER.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -84,7 +84,18 @@ void DotFileFormatTest::parseFileER()
 
     // Check that all of the node names were imported, and that there are no extras.
     QList<QString> nodeNames;
-    nodeNames << "course" << "institute" << "student" << "name0" << "name1" << "name2" << "code" << "grade" << "number" << "C-I" << "S-C" << "S-I";
+    nodeNames << "course"
+              << "institute"
+              << "student"
+              << "name0"
+              << "name1"
+              << "name2"
+              << "code"
+              << "grade"
+              << "number"
+              << "C-I"
+              << "S-C"
+              << "S-I";
     checkNodes(document, nodeNames);
 
     // Check the numbers of edges
@@ -105,14 +116,14 @@ void DotFileFormatTest::parseFileER()
             QVERIFY(node->dynamicProperty("label").toString() == "name");
         }
     }
-//     EdgePtr connection = from->edges(to).at(0); //FIXME API missing
-//     QVERIFY(connection->property("label") == "m");
+    //     EdgePtr connection = from->edges(to).at(0); //FIXME API missing
+    //     QVERIFY(connection->property("label") == "m");
 }
 
 void DotFileFormatTest::parseFileHeawood()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("undirected/Heawood.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -121,7 +132,7 @@ void DotFileFormatTest::parseFileHeawood()
 void DotFileFormatTest::parseFileNgk104()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("undirected/ngk10_4.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -130,7 +141,7 @@ void DotFileFormatTest::parseFileNgk104()
 void DotFileFormatTest::parseFilePetersen()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("undirected/Petersen.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -139,15 +150,14 @@ void DotFileFormatTest::parseFilePetersen()
 void DotFileFormatTest::parseFileProcess()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("undirected/process.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
     GraphDocumentPtr document = importer.graphDocument();
 
     // check that all of the node names were imported, and that there are no extras
-    QStringList nodeNames;
-    nodeNames << "run" << "intr" << "runbl" << "kernel" << "zombie" << "sleep" << "swap" << "runmem" << "runswap" << "new";
+    const QStringList nodeNames{"run", "intr", "runbl", "kernel", "zombie", "sleep", "swap", "runmem", "runswap", "new"};
     checkNodes(document, nodeNames);
     // Check the numbers of pointers
     QVERIFY(document->edges().count() == 13);
@@ -156,7 +166,7 @@ void DotFileFormatTest::parseFileProcess()
 void DotFileFormatTest::parseFileAbstract()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/abstract.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -165,7 +175,7 @@ void DotFileFormatTest::parseFileAbstract()
 void DotFileFormatTest::parseFileAlf()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/alf.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -174,7 +184,7 @@ void DotFileFormatTest::parseFileAlf()
 void DotFileFormatTest::parseFileArrows()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/arrows.gv"));
     importer.readFile();
     QEXPECT_FAIL("", "File contains invalid identifiers with underbar at beginning.", Continue);
@@ -184,7 +194,7 @@ void DotFileFormatTest::parseFileArrows()
 void DotFileFormatTest::parseFileAwilliams()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/awilliams.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -193,7 +203,7 @@ void DotFileFormatTest::parseFileAwilliams()
 void DotFileFormatTest::parseFileClust()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/clust.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -202,7 +212,7 @@ void DotFileFormatTest::parseFileClust()
 void DotFileFormatTest::parseFileClust1()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/clust1.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -211,7 +221,7 @@ void DotFileFormatTest::parseFileClust1()
 void DotFileFormatTest::parseFileClust2()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/clust2.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -220,7 +230,7 @@ void DotFileFormatTest::parseFileClust2()
 void DotFileFormatTest::parseFileClust3()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/clust3.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -229,7 +239,7 @@ void DotFileFormatTest::parseFileClust3()
 void DotFileFormatTest::parseFileClust4()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/clust4.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -238,7 +248,7 @@ void DotFileFormatTest::parseFileClust4()
 void DotFileFormatTest::parseFileClust5()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/clust5.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -247,7 +257,7 @@ void DotFileFormatTest::parseFileClust5()
 void DotFileFormatTest::parseFileCrazy()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/crazy.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -256,7 +266,7 @@ void DotFileFormatTest::parseFileCrazy()
 void DotFileFormatTest::parseFileCtext()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/ctext.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -265,7 +275,7 @@ void DotFileFormatTest::parseFileCtext()
 void DotFileFormatTest::parseFileDfa()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/dfa.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -274,7 +284,7 @@ void DotFileFormatTest::parseFileDfa()
 void DotFileFormatTest::parseFileFig6()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/fig6.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -283,15 +293,14 @@ void DotFileFormatTest::parseFileFig6()
 void DotFileFormatTest::parseFileFsm()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/fsm.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
     GraphDocumentPtr document = importer.graphDocument();
 
     // check that all of the node names were imported, and that there are no extras
-    QStringList nodeNames;
-    nodeNames << "LR_0" << "LR_1" << "LR_2" << "LR_3" << "LR_4" << "LR_5" << "LR_6" << "LR_7" << "LR_8";
+    const QStringList nodeNames{"LR_0", "LR_1", "LR_2", "LR_3", "LR_4", "LR_5", "LR_6", "LR_7", "LR_8"};
     checkNodes(document, nodeNames);
 
     // Check the numbers of pointers
@@ -312,14 +321,14 @@ void DotFileFormatTest::parseFileFsm()
             QVERIFY(node->property("shape").toString() == "circle");
         }
     }
-//     EdgePtr connection = from->edges(to).at(0); //FIXME API missing
-//     QVERIFY(connection->property("label") == "SS(B)");
+    //     EdgePtr connection = from->edges(to).at(0); //FIXME API missing
+    //     QVERIFY(connection->property("label") == "SS(B)");
 }
 
 void DotFileFormatTest::parseFileKW91()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/KW91.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -328,7 +337,7 @@ void DotFileFormatTest::parseFileKW91()
 void DotFileFormatTest::parseFileLatin1()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/Latin1.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -337,7 +346,7 @@ void DotFileFormatTest::parseFileLatin1()
 void DotFileFormatTest::parseFileNaN()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/NaN.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -346,7 +355,7 @@ void DotFileFormatTest::parseFileNaN()
 void DotFileFormatTest::parseFileGrammar()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/grammar.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -355,7 +364,7 @@ void DotFileFormatTest::parseFileGrammar()
 void DotFileFormatTest::parseFileHashtable()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/hashtable.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -364,7 +373,7 @@ void DotFileFormatTest::parseFileHashtable()
 void DotFileFormatTest::parseFileHondaTokoro()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/honda-tokoro.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -373,7 +382,7 @@ void DotFileFormatTest::parseFileHondaTokoro()
 void DotFileFormatTest::parseFileJapanese()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/japanese.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -382,7 +391,7 @@ void DotFileFormatTest::parseFileJapanese()
 void DotFileFormatTest::parseFileJcctree()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/jcctree.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -391,7 +400,7 @@ void DotFileFormatTest::parseFileJcctree()
 void DotFileFormatTest::parseFileJsort()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/jsort.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -400,7 +409,7 @@ void DotFileFormatTest::parseFileJsort()
 void DotFileFormatTest::parseFileLdbxtried()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/ldbxtried.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -409,7 +418,7 @@ void DotFileFormatTest::parseFileLdbxtried()
 void DotFileFormatTest::parseFileLongflat()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/longflat.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -418,7 +427,7 @@ void DotFileFormatTest::parseFileLongflat()
 void DotFileFormatTest::parseFileMike()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/mike.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -427,7 +436,7 @@ void DotFileFormatTest::parseFileMike()
 void DotFileFormatTest::parseFileNhg()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/nhg.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -436,7 +445,7 @@ void DotFileFormatTest::parseFileNhg()
 void DotFileFormatTest::parseFileOldarrows()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/oldarrows.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -445,7 +454,7 @@ void DotFileFormatTest::parseFileOldarrows()
 void DotFileFormatTest::parseFilePgram()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/pgram.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -454,7 +463,7 @@ void DotFileFormatTest::parseFilePgram()
 void DotFileFormatTest::parseFilePm2way()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/pm2way.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -463,7 +472,7 @@ void DotFileFormatTest::parseFilePm2way()
 void DotFileFormatTest::parseFilePmpipe()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/pmpipe.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -472,7 +481,7 @@ void DotFileFormatTest::parseFilePmpipe()
 void DotFileFormatTest::parseFilePolypoly()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/polypoly.gv"));
     importer.readFile();
     QEXPECT_FAIL("", "Not parsing with unknown reason: need to investigate further.", Continue);
@@ -482,7 +491,7 @@ void DotFileFormatTest::parseFilePolypoly()
 void DotFileFormatTest::parseFileProc3d()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/proc3d.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -491,7 +500,7 @@ void DotFileFormatTest::parseFileProc3d()
 void DotFileFormatTest::parseFilePsfonttest()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/psfonttest.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -500,7 +509,7 @@ void DotFileFormatTest::parseFilePsfonttest()
 void DotFileFormatTest::parseFileRecord2()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/record2.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -509,7 +518,7 @@ void DotFileFormatTest::parseFileRecord2()
 void DotFileFormatTest::parseFileRecords()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/records.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -518,7 +527,7 @@ void DotFileFormatTest::parseFileRecords()
 void DotFileFormatTest::parseFileRowe()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/rowe.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -527,7 +536,7 @@ void DotFileFormatTest::parseFileRowe()
 void DotFileFormatTest::parseFileRussian()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/russian.gv"));
     importer.readFile();
 
@@ -538,7 +547,7 @@ void DotFileFormatTest::parseFileRussian()
 void DotFileFormatTest::parseFileSdh()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/sdh.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -547,7 +556,7 @@ void DotFileFormatTest::parseFileSdh()
 void DotFileFormatTest::parseFileShells()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/shells.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -556,7 +565,7 @@ void DotFileFormatTest::parseFileShells()
 void DotFileFormatTest::parseFileStates()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/states.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -565,7 +574,7 @@ void DotFileFormatTest::parseFileStates()
 void DotFileFormatTest::parseFileStructs()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/structs.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -574,7 +583,7 @@ void DotFileFormatTest::parseFileStructs()
 void DotFileFormatTest::parseFileSwitch()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/switch.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -583,7 +592,7 @@ void DotFileFormatTest::parseFileSwitch()
 void DotFileFormatTest::parseFileTable()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/table.gv"));
     importer.readFile();
 
@@ -594,7 +603,7 @@ void DotFileFormatTest::parseFileTable()
 void DotFileFormatTest::parseFileTrain11()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/train11.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -603,7 +612,7 @@ void DotFileFormatTest::parseFileTrain11()
 void DotFileFormatTest::parseFileTrapeziumlr()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/trapeziumlr.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -612,7 +621,7 @@ void DotFileFormatTest::parseFileTrapeziumlr()
 void DotFileFormatTest::parseFileTree()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/tree.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -621,7 +630,7 @@ void DotFileFormatTest::parseFileTree()
 void DotFileFormatTest::parseFileTriedds()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/triedds.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -630,7 +639,7 @@ void DotFileFormatTest::parseFileTriedds()
 void DotFileFormatTest::parseFileTry()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/try.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -639,7 +648,7 @@ void DotFileFormatTest::parseFileTry()
 void DotFileFormatTest::parseFileUnix()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/unix.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -647,13 +656,47 @@ void DotFileFormatTest::parseFileUnix()
 
     // check that all of the node names were imported, and that there are no extra nodes
     QStringList nodeNames;
-    nodeNames << "5th Edition" << "6th Edition" << "PWB 1.0" << "LSX" << "1 BSD" << "Mini Unix"
-        << "Wollongong" << "Interdata" << "Unix/TS 3.0" << "PWB 2.0" << "7th Edition"
-        << "8th Edition" << "32V" << "V7M" << "Ultrix-11" << "Xenix" << "UniPlus+" << "9th Edition"
-        << "2 BSD" << "2.8 BSD" << "2.9 BSD" << "3 BSD" << "4 BSD" << "4.1 BSD" << "4.2 BSD"
-        << "4.3 BSD" << "Ultrix-32" << "PWB 1.2" << "USG 1.0" << "CB Unix 1" << "USG 2.0" <<
-        "CB Unix 2" << "CB Unix 3" << "Unix/TS++" << "PDP-11 Sys V" << "USG 3.0" << "Unix/TS 1.0"
-        << "TS 4.0" << "System V.0" << "System V.2" << "System V.3";
+    nodeNames << "5th Edition"
+              << "6th Edition"
+              << "PWB 1.0"
+              << "LSX"
+              << "1 BSD"
+              << "Mini Unix"
+              << "Wollongong"
+              << "Interdata"
+              << "Unix/TS 3.0"
+              << "PWB 2.0"
+              << "7th Edition"
+              << "8th Edition"
+              << "32V"
+              << "V7M"
+              << "Ultrix-11"
+              << "Xenix"
+              << "UniPlus+"
+              << "9th Edition"
+              << "2 BSD"
+              << "2.8 BSD"
+              << "2.9 BSD"
+              << "3 BSD"
+              << "4 BSD"
+              << "4.1 BSD"
+              << "4.2 BSD"
+              << "4.3 BSD"
+              << "Ultrix-32"
+              << "PWB 1.2"
+              << "USG 1.0"
+              << "CB Unix 1"
+              << "USG 2.0"
+              << "CB Unix 2"
+              << "CB Unix 3"
+              << "Unix/TS++"
+              << "PDP-11 Sys V"
+              << "USG 3.0"
+              << "Unix/TS 1.0"
+              << "TS 4.0"
+              << "System V.0"
+              << "System V.2"
+              << "System V.3";
     checkNodes(document, nodeNames);
 
     // check number of pointers
@@ -663,7 +706,7 @@ void DotFileFormatTest::parseFileUnix()
 void DotFileFormatTest::parseFileUnix2()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/unix2.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -672,7 +715,7 @@ void DotFileFormatTest::parseFileUnix2()
 void DotFileFormatTest::parseFileViewfile()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/viewfile.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -681,7 +724,7 @@ void DotFileFormatTest::parseFileViewfile()
 void DotFileFormatTest::parseFileWorld()
 {
     // create importer plugin
-    DotFileFormat importer(this, QList<QVariant>());
+    DotFileFormat importer(this, KPluginMetaData(), QVariantList());
     importer.setFile(QUrl::fromLocalFile("directed/world.gv"));
     importer.readFile();
     QVERIFY2(importer.hasError() == false, importer.errorString().toStdString().c_str());
@@ -698,7 +741,7 @@ void DotFileFormatTest::writeAndParseTest()
     Edge::create(nodes["a"], nodes["b"]);
 
     // create testfile
-    DotFileFormat dotFormat(this, QList<QVariant>());
+    DotFileFormat dotFormat(this, KPluginMetaData(), QVariantList());
     QTemporaryFile testFile;
     testFile.open();
     dotFormat.setFile(QUrl::fromLocalFile(testFile.fileName()));
