@@ -15,8 +15,8 @@ using namespace GraphTheory;
 class GraphTheory::FileFormatInterfacePrivate
 {
 public:
-    FileFormatInterfacePrivate(const QString &componentName)
-        : componentName(componentName)
+    FileFormatInterfacePrivate(const KPluginMetaData &data)
+        : componentName(data.name())
     {
         lastError = FileFormatInterface::None;
     }
@@ -28,16 +28,14 @@ public:
     QUrl file;
 };
 
-
-FileFormatInterface::FileFormatInterface(const QString &componentName, QObject *parent):
-    QObject(parent),
-    d(new FileFormatInterfacePrivate(componentName))
+FileFormatInterface::FileFormatInterface(QObject *parent, const KPluginMetaData &data)
+    : QObject(parent)
+    , d(new FileFormatInterfacePrivate(data))
 {
 }
 
 FileFormatInterface::~FileFormatInterface()
 {
-
 }
 
 FileFormatInterface::PluginType FileFormatInterface::pluginCapability() const
@@ -87,7 +85,7 @@ void FileFormatInterface::setFile(const QUrl &file)
     d->file = file;
 }
 
-const QUrl& FileFormatInterface::file() const
+const QUrl &FileFormatInterface::file() const
 {
     return d->file;
 }
