@@ -5,30 +5,28 @@
  */
 
 #include "rocs2fileformat.h"
-#include "modifiers/topology.h"
-#include "graphdocument.h"
-#include "node.h"
 #include "edge.h"
 #include "edgetypestyle.h"
-#include "nodetypestyle.h"
+#include "graphdocument.h"
 #include "logging_p.h"
-#include <algorithm>
+#include "modifiers/topology.h"
+#include "node.h"
+#include "nodetypestyle.h"
 #include <KLocalizedString>
 #include <KPluginFactory>
+#include <QFile>
+#include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
-#include <QJsonArray>
-#include <QFile>
 #include <QUrl>
+#include <algorithm>
 
 using namespace GraphTheory;
 
-K_PLUGIN_FACTORY_WITH_JSON( FilePluginFactory,
-                            "rocs2fileformat.json",
-                            registerPlugin<Rocs2FileFormat>();)
+K_PLUGIN_CLASS_WITH_JSON(Rocs2FileFormat, "rocs2fileformat.json")
 
-Rocs2FileFormat::Rocs2FileFormat(QObject* parent, const QList< QVariant >&)
-    : FileFormatInterface("rocs_tgffileformat", parent)
+Rocs2FileFormat::Rocs2FileFormat(QObject *parent, const KPluginMetaData &data, const QVariantList &)
+    : FileFormatInterface(parent, data)
 {
 }
 
@@ -38,8 +36,9 @@ Rocs2FileFormat::~Rocs2FileFormat()
 
 const QStringList Rocs2FileFormat::extensions() const
 {
-    return QStringList()
-           << i18n("Rocs Graph Format (%1)", QString("*.graph2")); // do not confuse with Rocs-1 format
+    return QStringList{
+        i18n("Rocs Graph Format (%1)", QString("*.graph2")) // do not confuse with Rocs-1 format
+    };
 }
 
 void Rocs2FileFormat::readFile()
@@ -126,7 +125,7 @@ void Rocs2FileFormat::readFile()
 
         // set type
         NodeTypePtr typeToSet;
-        //TODO this is not very efficient for big files: use table instead to cache IDs
+        // TODO this is not very efficient for big files: use table instead to cache IDs
         const auto nodeTypes = document->nodeTypes();
         for (const NodeTypePtr &type : nodeTypes) {
             if (type->id() == nodeJson["Type"].toInt()) {
@@ -160,7 +159,7 @@ void Rocs2FileFormat::readFile()
 
         // find nodes to connect to
         NodePtr fromNode, toNode;
-        //TODO this is not very efficient for big files: use table instead to cache IDs
+        // TODO this is not very efficient for big files: use table instead to cache IDs
         const auto nodes = document->nodes();
         for (const NodePtr &node : nodes) {
             if (node->id() == edgeJson["From"].toInt()) {
@@ -171,15 +170,15 @@ void Rocs2FileFormat::readFile()
             }
         }
         if (!fromNode || !toNode) {
-            qCCritical(GRAPHTHEORY_FILEFORMAT) << "No type found with this ID, aborting edge from"
-                << edgeJson["From"].toInt() << "to" << edgeJson["To"].toInt();
+            qCCritical(GRAPHTHEORY_FILEFORMAT) << "No type found with this ID, aborting edge from" << edgeJson["From"].toInt() << "to"
+                                               << edgeJson["To"].toInt();
             continue;
         }
         EdgePtr edge = Edge::create(fromNode, toNode);
 
         // set type
         EdgeTypePtr typeToSet;
-        //TODO this is not very efficient for big files: use table instead to cache IDs
+        // TODO this is not very efficient for big files: use table instead to cache IDs
         const auto edgeTypes = document->edgeTypes();
         for (const EdgeTypePtr &type : edgeTypes) {
             if (type->id() == edgeJson["Type"].toInt()) {
