@@ -6,52 +6,39 @@
 
 #include "nodetypemodel.h"
 #include "graphdocument.h"
-#include "nodetypestyle.h"
 #include "logging_p.h"
+#include "nodetypestyle.h"
 
 #include <KLocalizedString>
 #include <QSignalMapper>
 
 using namespace GraphTheory;
 
-class GraphTheory::NodeTypeModelPrivate {
+class GraphTheory::NodeTypeModelPrivate
+{
 public:
-    NodeTypeModelPrivate()
-        : m_signalMapper(new QSignalMapper)
-    {
-    }
-
-    ~NodeTypeModelPrivate()
-    {
-        m_signalMapper->deleteLater();
-    }
-
     void updateMappings()
     {
         int types = m_document->nodeTypes().count();
         for (int i = 0; i < types; ++i) {
-            m_signalMapper->setMapping(m_document->nodeTypes().at(i).data(), i);
+            m_signalMapper.setMapping(m_document->nodeTypes().at(i).data(), i);
         }
     }
 
     GraphDocumentPtr m_document;
-    QSignalMapper *m_signalMapper;
+    QSignalMapper m_signalMapper;
 };
 
 NodeTypeModel::NodeTypeModel(QObject *parent)
     : QAbstractListModel(parent)
     , d(new NodeTypeModelPrivate)
 {
-    connect(d->m_signalMapper, static_cast<void (QSignalMapper::*)(int)>(&QSignalMapper::mapped),
-        this, &NodeTypeModel::emitNodeTypeChanged);
+    connect(&d->m_signalMapper, &QSignalMapper::mappedInt, this, &NodeTypeModel::emitNodeTypeChanged);
 }
 
-NodeTypeModel::~NodeTypeModel()
-{
+NodeTypeModel::~NodeTypeModel() = default;
 
-}
-
-QHash< int, QByteArray > NodeTypeModel::roleNames() const
+QHash<int, QByteArray> NodeTypeModel::roleNames() const
 {
     QHash<int, QByteArray> roles;
     roles[IdRole] = "id";
@@ -78,14 +65,10 @@ void NodeTypeModel::setDocument(GraphDocumentPtr document)
     }
     d->m_document = document;
     if (d->m_document) {
-        connect(d->m_document.data(), &GraphDocument::nodeTypeAboutToBeAdded,
-            this, &NodeTypeModel::onNodeTypeAboutToBeAdded);
-        connect(d->m_document.data(), &GraphDocument::nodeTypeAdded,
-            this, &NodeTypeModel::onNodeTypeAdded);
-        connect(d->m_document.data(), &GraphDocument::nodeTypesAboutToBeRemoved,
-            this, &NodeTypeModel::onNodeTypesAboutToBeRemoved);
-        connect(d->m_document.data(), &GraphDocument::nodeTypesRemoved,
-            this, &NodeTypeModel::onNodeTypesRemoved);
+        connect(d->m_document.data(), &GraphDocument::nodeTypeAboutToBeAdded, this, &NodeTypeModel::onNodeTypeAboutToBeAdded);
+        connect(d->m_document.data(), &GraphDocument::nodeTypeAdded, this, &NodeTypeModel::onNodeTypeAdded);
+        connect(d->m_document.data(), &GraphDocument::nodeTypesAboutToBeRemoved, this, &NodeTypeModel::onNodeTypesAboutToBeRemoved);
+        connect(d->m_document.data(), &GraphDocument::nodeTypesRemoved, this, &NodeTypeModel::onNodeTypesRemoved);
     }
     endResetModel();
     Q_EMIT documentChanged();
@@ -109,8 +92,7 @@ QVariant NodeTypeModel::data(const QModelIndex &index, int role) const
 
     NodeTypePtr const type = d->m_document->nodeTypes().at(index.row());
 
-    switch(role)
-    {
+    switch (role) {
     case IdRole:
         return type->id();
     case TitleRole:
@@ -118,7 +100,7 @@ QVariant NodeTypeModel::data(const QModelIndex &index, int role) const
     case ColorRole:
         return type->style()->color();
     case DataRole:
-        return QVariant::fromValue<QObject*>(type.data());
+        return QVariant::fromValue<QObject *>(type.data());
     default:
         return QVariant();
     }
@@ -137,8 +119,7 @@ bool NodeTypeModel::setData(const QModelIndex &index, const QVariant &value, int
     }
 
     NodeTypePtr const type = d->m_document->nodeTypes().at(index.row());
-    switch(role)
-    {
+    switch (role) {
     case IdRole:
         type->setId(value.toInt());
         return true;
@@ -169,12 +150,9 @@ int NodeTypeModel::rowCount(const QModelIndex &parent) const
 void NodeTypeModel::onNodeTypeAboutToBeAdded(NodeTypePtr type, int index)
 {
     beginInsertRows(QModelIndex(), index, index);
-    connect(type.data(), &NodeType::idChanged,
-        d->m_signalMapper, static_cast<void (QSignalMapper::*)(void)>(&QSignalMapper::map));
-    connect(type.data(), &NodeType::nameChanged,
-        d->m_signalMapper, static_cast<void (QSignalMapper::*)(void)>(&QSignalMapper::map));
-    connect(type.data(), &NodeType::colorChanged,
-        d->m_signalMapper, static_cast<void (QSignalMapper::*)(void)>(&QSignalMapper::map));
+    connect(type.data(), &NodeType::idChanged, &d->m_signalMapper, static_cast<void (QSignalMapper::*)(void)>(&QSignalMapper::map));
+    connect(type.data(), &NodeType::nameChanged, &d->m_signalMapper, static_cast<void (QSignalMapper::*)(void)>(&QSignalMapper::map));
+    connect(type.data(), &NodeType::colorChanged, &d->m_signalMapper, static_cast<void (QSignalMapper::*)(void)>(&QSignalMapper::map));
 }
 
 void NodeTypeModel::onNodeTypeAdded()
