@@ -10,28 +10,26 @@
 #include <KColorButton>
 #include <KLocalizedString>
 #include <QAbstractItemView>
-#include <QToolButton>
+#include <QApplication>
+#include <QDebug>
 #include <QLabel>
 #include <QLineEdit>
 #include <QPainter>
 #include <QPointer>
-#include <QApplication>
-#include <QDebug>
+#include <QToolButton>
 
 using namespace GraphTheory;
 
-EdgeTypesDelegate::EdgeTypesDelegate(QAbstractItemView* parent)
+EdgeTypesDelegate::EdgeTypesDelegate(QAbstractItemView *parent)
     : KWidgetItemDelegate(parent, parent->viewport())
 {
-
 }
 
 EdgeTypesDelegate::~EdgeTypesDelegate()
 {
-
 }
 
-void EdgeTypesDelegate::paint(QPainter* painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
+void EdgeTypesDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     if (!index.isValid()) {
         return;
@@ -39,15 +37,15 @@ void EdgeTypesDelegate::paint(QPainter* painter, const QStyleOptionViewItem &opt
     QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, nullptr);
 }
 
-QSize EdgeTypesDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
+QSize EdgeTypesDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     Q_UNUSED(index);
-    int iconHeight = option.decorationSize.height() + (m_vPadding * 2); //icon height + padding either side
-    int textHeight = option.fontMetrics.height()*2 + (m_vPadding * 2) + 10; // text height * 2 + padding + some space between the lines
-    return QSize(-1,qMax(iconHeight, textHeight)); // any width, he view should give us the whole thing
+    int iconHeight = option.decorationSize.height() + (m_vPadding * 2); // icon height + padding either side
+    int textHeight = option.fontMetrics.height() * 2 + (m_vPadding * 2) + 10; // text height * 2 + padding + some space between the lines
+    return QSize(-1, qMax(iconHeight, textHeight)); // any width, he view should give us the whole thing
 }
 
-QList< QWidget* > EdgeTypesDelegate::createItemWidgets(const QModelIndex &index) const
+QList<QWidget *> EdgeTypesDelegate::createItemWidgets(const QModelIndex &index) const
 {
     // items created by this method and added to the return-list will be
     // deleted by KWidgetItemDelegate
@@ -70,10 +68,10 @@ QList< QWidget* > EdgeTypesDelegate::createItemWidgets(const QModelIndex &index)
     connect(title, &QLineEdit::textEdited, this, &EdgeTypesDelegate::onNameChanged);
     connect(propertiesButton, &QToolButton::clicked, this, &EdgeTypesDelegate::showPropertiesDialog);
 
-    return { colorButton, direction, title, idLabel, propertiesButton };
+    return {colorButton, direction, title, idLabel, propertiesButton};
 }
 
-void EdgeTypesDelegate::updateItemWidgets(const QList< QWidget* > widgets, const QStyleOptionViewItem& option, const QPersistentModelIndex& index) const
+void EdgeTypesDelegate::updateItemWidgets(const QList<QWidget *> widgets, const QStyleOptionViewItem &option, const QPersistentModelIndex &index) const
 {
     // widgets:
     // Color | Direction | Title | ID
@@ -84,11 +82,11 @@ void EdgeTypesDelegate::updateItemWidgets(const QList< QWidget* > widgets, const
 
     Q_ASSERT(widgets.size() == 5);
 
-    KColorButton *colorButton = qobject_cast<KColorButton*>(widgets.at(0));
-    QToolButton *directionSwitch = qobject_cast<QToolButton*>(widgets.at(1));
-    QLineEdit *title = qobject_cast<QLineEdit*>(widgets.at(2));
-    QLabel *id = qobject_cast<QLabel*>(widgets.at(3));
-    QToolButton *propertiesButton = qobject_cast<QToolButton*>(widgets.at(4));
+    KColorButton *colorButton = qobject_cast<KColorButton *>(widgets.at(0));
+    QToolButton *directionSwitch = qobject_cast<QToolButton *>(widgets.at(1));
+    QLineEdit *title = qobject_cast<QLineEdit *>(widgets.at(2));
+    QLabel *id = qobject_cast<QLabel *>(widgets.at(3));
+    QToolButton *propertiesButton = qobject_cast<QToolButton *>(widgets.at(4));
 
     Q_ASSERT(colorButton);
     Q_ASSERT(directionSwitch);
@@ -112,7 +110,7 @@ void EdgeTypesDelegate::updateItemWidgets(const QList< QWidget* > widgets, const
     int colorButtonTopMargin = (outerRect.height() - colorButton->height()) / 2;
     colorButton->move(colorButtonLeftMargin, colorButtonTopMargin);
 
-    int directionSwitchLeftMargin = colorButtonLeftMargin + + colorButton->width() + 10;
+    int directionSwitchLeftMargin = colorButtonLeftMargin + +colorButton->width() + 10;
     int directionSwitchTopMargin = (outerRect.height() - directionSwitch->height()) / 2;
     directionSwitch->move(directionSwitchLeftMargin, directionSwitchTopMargin);
 
@@ -129,7 +127,6 @@ void EdgeTypesDelegate::updateItemWidgets(const QList< QWidget* > widgets, const
     int idTopMargin = (outerRect.height() - id->height()) / 2;
     id->move(idLeftMargin, idTopMargin);
 
-
     // title gets remaining space
     title->setFixedWidth(qMax(0, idLeftMargin - titleLeftMargin - 10));
 }
@@ -155,12 +152,9 @@ void EdgeTypesDelegate::onNameChanged(const QString &name)
 void EdgeTypesDelegate::onDirectionSwitched()
 {
     QModelIndex index = focusedIndex();
-    EdgeType::Direction direction = static_cast<EdgeType::Direction>(
-        index.data(EdgeTypeModel::DirectionRole).toInt());
+    EdgeType::Direction direction = static_cast<EdgeType::Direction>(index.data(EdgeTypeModel::DirectionRole).toInt());
 
-    const EdgeType::Direction newDirection = direction == EdgeType::Bidirectional
-        ? EdgeType::Unidirectional
-        : EdgeType::Bidirectional;
+    const EdgeType::Direction newDirection = direction == EdgeType::Bidirectional ? EdgeType::Unidirectional : EdgeType::Bidirectional;
 
     Q_EMIT directionChanged(index, newDirection);
 }
@@ -168,7 +162,7 @@ void EdgeTypesDelegate::onDirectionSwitched()
 void EdgeTypesDelegate::showPropertiesDialog()
 {
     QModelIndex index = focusedIndex();
-    EdgeType *type = qobject_cast<EdgeType*>(index.data(EdgeTypeModel::DataRole).value<QObject*>());
+    EdgeType *type = qobject_cast<EdgeType *>(index.data(EdgeTypeModel::DataRole).value<QObject *>());
     QPointer<EdgeTypeProperties> dialog = new EdgeTypeProperties(nullptr);
     dialog->setType(type->self());
     dialog->exec();
